AsyncEventQueue<Id> class

Constructors

AsyncEventQueue({bool allowAsyncFor(Id e1, Id e2)?})

Properties

allowAsyncFor bool Function(Id e1, Id e2)?
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call<T>(EventQueueCallback<T> event, {Id? eventId}) Future<T?>
clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transform(QueueTransformer<Id> transformer) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited