EventQueue<Id> class

Properties

hashCode int
The hash code for this object.
no setterinherited
isCleared bool
Set to true when calling clear(). Set to false again when a new event is processed. Use it if you need to cancel any currently processing work, in addition to clearing the upcoming items.
no setter
isEmpty bool
no setter
queueTransformer QueueTransformer<Id>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call<T>(EventQueueCallback<T> event, {Id? eventId}) Future<T?>
clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transform(QueueTransformer<Id> transformer) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited