ReadWriteEventQueue class
Sequential reads are allowed to be async.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void -
clearWrites(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read<
T> (EventQueueCallback< T> event) → Future<T?> -
toString(
) → String -
A string representation of this object.
inherited
-
write<
T> (EventQueueCallback< T> event) → Future<T?>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited